@@ -140,9 +140,9 @@ static PyObject *py_setup_gpioport(PyObject *self, PyObject *args, PyObject *kwa
 #if PY_MAJOR_VERSION > 2
    if (PyLong_Check(gpiolist)) {
       gpioport = (int)PyLong_AsLong(gpiolist);
-#else
-   if (PyInt_Check(gpiolist)) {
-      gpioport = (int)PyInt_AsLong(gpiolist);
+//#else
+//   if (PyInt_Check(gpiolist)) {
+//      gpioport = (int)PyInt_AsLong(gpiolist);
 #endif
       if (PyErr_Occurred())
          return NULL;
@@ -202,9 +202,9 @@ static PyObject *py_setup_gpioport(PyObject *self, PyObject *args, PyObject *kwa
 #if PY_MAJOR_VERSION > 2
       if (PyLong_Check(tempobj)) {
          gpioport = (int)PyLong_AsLong(tempobj);
-#else
-      if (PyInt_Check(tempobj)) {
-         gpioport = (int)PyInt_AsLong(tempobj);
+//#else
+//      if (PyInt_Check(tempobj)) {
+//         gpioport = (int)PyInt_AsLong(tempobj);
 #endif
          if (PyErr_Occurred())
              return NULL;
@@ -234,6 +234,7 @@ static PyObject *py_output_gpio(PyObject *self, PyObject *args)
    PyObject *valuetuple = NULL;
    PyObject *tempobj = NULL;
 
+
    if (!PyArg_ParseTuple(args, "OO", &gpiolist, &valuelist))
        return NULL;
 
@@ -260,9 +261,9 @@ static PyObject *py_output_gpio(PyObject *self, PyObject *args)
 #if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(valuelist)) {
        value = (int)PyLong_AsLong(valuelist);
-#else
-   if (PyInt_Check(valuelist)) {
-       value = (int)PyInt_AsLong(valuelist);
+//#else
+//   if (PyInt_Check(valuelist)) {
+//       value = (int)PyInt_AsLong(valuelist);
 #endif
       if (PyErr_Occurred())
          return NULL;
@@ -386,8 +387,8 @@ static PyObject *py_input_gpio(PyObject *self, PyObject *args)
 static const char moduledocstring[] = "Python GPIO module for starfive";
 
 PyMethodDef sfv_gpio_methods[] = {
-	{"setup", (PyCFunction)py_setup_gpioport, METH_VARARGS | METH_KEYWORDS, "Setup direction"},
-	{"cleanup", (PyCFunction)py_cleanup, METH_VARARGS | METH_KEYWORDS, "set default."},
+	{"setup", (PyCFunction)py_setup_gpioport, METH_VARARGS | METH_KEYWORDS, "Set up a GPIO gpioport or list of gpioports with a direction and (optional) pull/up down control\ngpioport        - either board pin number or BCM number depending on which mode is set.\ndirection      - IN or OUT\n[pull_up_down] - PUD_OFF (default), PUD_UP or PUD_DOWN\n[initial]      - Initial value for an output gpioport"},
+	{"cleanup", (PyCFunction)py_cleanup, METH_VARARGS | METH_KEYWORDS, "Clean up by resetting all GPIO gpioports that have been used by this program to INPUT with no pullup/pulldown and no event detection\n[gpioport] - individual gpioport or list/tuple of gpioports to clean up.  Default - clean every gpioport that has been used."},
 	{"output", py_output_gpio, METH_VARARGS, "Output to a GPIO gpioport or list of gpioports\ngpioport - either board pin number or BCM number depending on which mode is set.\nvalue   - 0/1 or False/True or LOW/HIGH"},
 	{"input", py_input_gpio, METH_VARARGS, "Input from a GPIO gpioport.	Returns HIGH=1=True or LOW=0=False\ngpioport - either board pin number or BCM number depending on which mode is set."},
 	{NULL, NULL, 0, NULL}
@@ -422,7 +423,7 @@ PyMODINIT_FUNC init_GPIO(void)
 
    define_py_constants(module);
 
-   for (i=0; i<49; i++)
+   for (i=0; i<54; i++)
       gpio_direction[i] = -1;
 
    // Add TH class
