@@ -14,7 +14,7 @@ def main():
         tem = th1.getTem()
         hum = th1.getHum()
         print("Temperature = {:.2f}℃, Humidity = {:.2f} % \n".format(tem, hum))
-        i++
+        i = i + 1
 
     th1.stop()
 
